@@ -128,9 +128,9 @@ List ProbabilityMatrixDiagonal45Dynamic(NumericMatrix vMat, int d, bool narm,
       for(int j = 0; j < out.ncol(); j++){
         for(int a = 0; a < xMat.nrow(); a++){
           for(int b = 0; b < xMat.ncol(); b++){
-            if( (b >= d) & (a < xMat.nrow() - d) ){
+            if( (b >= d) && (a < xMat.nrow() - d) ){
 
-              if((Values(i) == xMat(a,b)) && (Values(j) == xMat(a+d, b-d))){
+              if(Values(i) == xMat(a,b) && Values(j) == xMat(a+d, b-d)){
                 out(i,j) += 1;
 
               }
